@@ -85,8 +85,8 @@ static const struct canon_entry_table_t {
   { 3,  2, N_("On")},
   { 3,  3, N_("Red-eye reduction")},
   { 3,  4, N_("Slow synchro")},
-  { 3,  5, N_("Auto + Red-eye reduction")},
-  { 3,  6, N_("On + Red-eye reduction")},
+  { 3,  5, N_("Auto, red-eye reduction")},
+  { 3,  6, N_("On, red-eye reduction")},
   { 3, 16, N_("External flash")},
   { 4,  0, N_("Single")},
   { 4,  1, N_("Continuous")},
@@ -210,16 +210,18 @@ static const struct canon_entry_table_t {
   {21,  11, N_("Canon EF 35mm f/2")},
   {21,  13, N_("Canon EF 15mm f/2.8")},
   {21,  21, N_("Canon EF 80-200mm f/2.8L")},
-  {21,  22, N_("Tokina AT-X280AF PRO 28-80mm F2.8 ASPHERICAL")},
+  {21,  22, N_("Tokina AT-X280AF PRO 28-80mm F2.8 Aspherical")},
   {21,  26, N_("Cosina 100mm f/3.5 Macro AF")},
   {21,  28, N_("Tamron AF Aspherical 28-200mm f/3.8-5.6")},
   {21,  29, N_("Canon EF 50mm f/1.8 MkII")},
   {21,  31, N_("Tamron SP AF 300mm f/2.8 LD IF")},
   {21,  32, N_("Canon EF 24mm f/2.8 or Sigma 15mm f/2.8 EX Fisheye")},
+  {21,  37, N_("Canon EF 35-80mm f/4-5.6")},
   {21,  39, N_("Canon EF 75-300mm f/4-5.6")},
   {21,  40, N_("Canon EF 28-80mm f/3.5-5.6")},
   {21,  43, N_("Canon EF 28-105mm f/4-5.6")},
   {21,  45, N_("Canon EF-S 18-55mm f/3.5-5.6")},
+  {21,  52, N_("Canon EF-S 18-55mm f/3.5-5.6 IS II")},
   {21, 124, N_("Canon MP-E 65mm f/2.8 1-5x Macro Photo")},
   {21, 125, N_("Canon TS-E 24mm f/3.5L")},
   {21, 126, N_("Canon TS-E 45mm f/2.8")},
@@ -282,6 +284,7 @@ static const struct canon_entry_table_t {
   {21, 238, N_("Canon EF 70-300mm F4-5.6 IS USM")},
   {21, 241, N_("Canon EF 50mm F1.2L USM")},
   {21, 242, N_("Canon EF 70-200mm f/4L IS USM")},
+  {21, 251, N_("Canon EF 70-200mm f/2.8L IS II USM")},
   {28, 0, N_("Manual")},
   {28, 1, N_("TTL")},
   {28, 2, N_("A-TTL")},
@@ -296,7 +299,7 @@ static const struct canon_entry_table_t {
   {32, 0, N_("Normal AE")},
   {32, 1, N_("Exposure compensation")},
   {32, 2, N_("AE lock")},
-  {32, 3, N_("AE lock + Exposure compensation")},
+  {32, 3, N_("AE lock + exposure compensation")},
   {32, 4, N_("No AE")},
   {33, 0, N_("Off")},
   {33, 1, N_("On")},
@@ -349,10 +352,10 @@ entries_settings_2 [] = {
   { 13,  0x3000, N_("None (MF)")},
   { 13,  0x3001, N_("Right")},
   { 13,  0x3002, N_("Center")},
-  { 13,  0x3003, N_("Center + Right")},
+  { 13,  0x3003, N_("Center-right")},
   { 13,  0x3004, N_("Left")},
-  { 13,  0x3005, N_("Left + Right")},
-  { 13,  0x3006, N_("Left + Center")},
+  { 13,  0x3005, N_("Left-right")},
+  { 13,  0x3006, N_("Left-center")},
   { 13,  0x3007, N_("All")},
   { 15,  0, N_("Off")},
   { 15,  1, N_("On (shot 1)")},
@@ -404,13 +407,13 @@ color_information [] = {
   {7,  4, N_("Fluorescent")},
   {7,  5, N_("Flash")},
   {7,  6, N_("Custom")},
-  {7,  7, N_("Black & White")},
+  {7,  7, N_("Black & white")},
   {7,  8, N_("Shade")},
-  {7,  9, N_("Manual Temperature (Kelvin)")},
-  {7, 10, N_("PC Set1")},
-  {7, 11, N_("PC Set2")},
-  {7, 12, N_("PC Set3")},
-  {7, 14, N_("Daylight Fluorescent")},
+  {7,  9, N_("Manual temperature (Kelvin)")},
+  {7, 10, N_("PC set 1")},
+  {7, 11, N_("PC set 2")},
+  {7, 12, N_("PC set 3")},
+  {7, 14, N_("Daylight fluorescent")},
   {7, 15, N_("Custom 1")},
   {7, 16, N_("Custom 2")},
   {7, 17, N_("Underwater")},
@@ -419,9 +422,9 @@ color_information [] = {
   {9, 0x02, N_("Set 1")},
   {9, 0x03, N_("Set 2")},
   {9, 0x04, N_("Set 3")},
-  {9, 0x21, N_("User Def. 1")},
-  {9, 0x22, N_("User Def. 2")},
-  {9, 0x23, N_("User Def. 3")},
+  {9, 0x21, N_("User def. 1")},
+  {9, 0x22, N_("User def. 2")},
+  {9, 0x23, N_("User def. 3")},
   {9, 0x41, N_("External 1")},
   {9, 0x42, N_("External 2")},
   {9, 0x43, N_("External 3")},
