@@ -1,6 +1,6 @@
 /* i18n.h
  *
- * Copyright  2001 Lutz Mller <lutz@users.sourceforge.net>
+ * Copyright (c) 2001 Lutz Mueller <lutz@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -14,13 +14,15 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA.
  */
 
 #ifndef __I18N_H__
 #define __I18N_H__
 
+#include "config.h"
+
 #ifdef ENABLE_NLS
 #  include <libintl.h>
 #  undef _
@@ -33,10 +35,16 @@
 #else
 #  define textdomain(String) (String)
 #  define gettext(String) (String)
+#  define ngettext(String1,String2,Count) (Count==1?String1:String2)
 #  define dgettext(Domain,Message) (Message)
 #  define dcgettext(Domain,Message,Type) (Message)
-#  define bind_textdomain_codeset(Domain,Codeset) (Codeset)
-#  define bindtextdomain(Domain,Directory) (Domain)
+#ifdef __WATCOMC__
+#    define bind_textdomain_codeset(Domain,Codeset)
+#    define bindtextdomain(Domain,Directory)
+#else
+#    define bind_textdomain_codeset(Domain,Codeset) (Codeset)
+#    define bindtextdomain(Domain,Directory) (Domain)
+#endif
 #  define _(String) (String)
 #  define N_(String) (String)
 #endif
