@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA.
  */
 
 #include <config.h>
@@ -75,7 +75,7 @@ static const struct {
 #ifndef NO_VERBOSE_TAG_DATA
   { MNOTE_PENTAX_TAG_MODE,
     { {0, N_("Auto")},
-      {1, N_("Night-scene")},
+      {1, N_("Night scene")},
       {2, N_("Manual")},
       {4, N_("Multi-exposure")},
       {0, NULL}}},
@@ -91,7 +91,7 @@ static const struct {
     { {1, N_("Auto")},
       {2, N_("Flash on")},
       {4, N_("Flash off")},
-      {6, N_("Red-eye Reduction")},
+      {6, N_("Red-eye reduction")},
       {0, NULL}}},
   { MNOTE_PENTAX_TAG_WHITE_BALANCE,
     { {0, N_("Auto")},
@@ -124,12 +124,12 @@ static const struct {
       { 0,  NULL}}},
   { MNOTE_PENTAX_TAG_COLOR,
     { {1, N_("Full")},
-      {2, N_("Black & White")},
+      {2, N_("Black & white")},
       {3, N_("Sepia")},
       {0, NULL}}},
   { MNOTE_PENTAX2_TAG_MODE,
     { {0, N_("Auto")},
-      {1, N_("Night-scene")},
+      {1, N_("Night scene")},
       {2, N_("Manual")},
       {4, N_("Multi-exposure")},
       {0, NULL}}},
@@ -166,50 +166,50 @@ static const struct {
       {5, N_("Portrait")},
       {6, N_("Landscape")},
       {8, N_("Sport")},
-      {9, N_("Night Scene")},
+      {9, N_("Night scene")},
       {11, N_("Soft")},
-      {12, N_("Surf & Snow")},
-      {13, N_("Sunset or Candlelight")},
+      {12, N_("Surf & snow")},
+      {13, N_("Sunset or candlelight")},
       {14, N_("Autumn")},
       {15, N_("Macro")},
       {17, N_("Fireworks")},
       {18, N_("Text")},
       {19, N_("Panorama")},
-      {30, N_("Self Portrait")},
+      {30, N_("Self portrait")},
       {31, N_("Illustrations")},
-      {33, N_("Digital Filter")},
+      {33, N_("Digital filter")},
       {37, N_("Museum")},
       {38, N_("Food")},
-      {40, N_("Green Mode")},
-      {49, N_("Light Pet")},
-      {50, N_("Dark Pet")},
-      {51, N_("Medium Pet")},
+      {40, N_("Green mode")},
+      {49, N_("Light pet")},
+      {50, N_("Dark pet")},
+      {51, N_("Medium pet")},
       {53, N_("Underwater")},
       {54, N_("Candlelight")},
-      {55, N_("Natural Skin Tone")},
-      {56, N_("Synchro Sound Record")},
-      {58, N_("Frame Composite")},
+      {55, N_("Natural skin tone")},
+      {56, N_("Synchro sound record")},
+      {58, N_("Frame composite")},
       {0, NULL}}},
   { MNOTE_PENTAX2_TAG_FLASH_MODE,
-    { {0x0000, N_("Auto, Did not fire")},
+    { {0x0000, N_("Auto, did not fire")},
       {0x0001, N_("Off")},
-      {0x0003, N_("Auto, Did not fire, Red-eye reduction")},
-      {0x0100, N_("Auto, Fired")},
+      {0x0003, N_("Auto, did not fire, red-eye reduction")},
+      {0x0100, N_("Auto, fired")},
       {0x0102, N_("On")},
-      {0x0103, N_("Auto, Fired, Red-eye reduction")},
-      {0x0104, N_("On, Red-eye reduction")},
-      {0x0105, N_("On, Wireless")},
-      {0x0108, N_("On, Soft")},
-      {0x0109, N_("On, Slow-sync")},
-      {0x010a, N_("On, Slow-sync, Red-eye reduction")},
-      {0x010b, N_("On, Trailing-curtain Sync")},
+      {0x0103, N_("Auto, fired, red-eye reduction")},
+      {0x0104, N_("On, red-eye reduction")},
+      {0x0105, N_("On, wireless")},
+      {0x0108, N_("On, soft")},
+      {0x0109, N_("On, slow-sync")},
+      {0x010a, N_("On, slow-sync, red-eye reduction")},
+      {0x010b, N_("On, trailing-curtain sync")},
       {0, NULL}}},
   { MNOTE_PENTAX2_TAG_FOCUS_MODE,
     { {0, N_("Normal")},
       {1, N_("Macro")},
       {2, N_("Infinity")},
       {3, N_("Manual")},
-      {5, N_("Pan Focus")},
+      {5, N_("Pan focus")},
       {16, N_("AF-S")},
       {17, N_("AF-C")},
       {0, NULL}}},
@@ -225,7 +225,7 @@ static const struct {
       {9, N_("Lower-left")},
       {10, N_("Bottom")},
       {11, N_("Lower-right")},
-      {0xfffe, N_("Fixed Center")},
+      {0xfffe, N_("Fixed center")},
       {0xffff, N_("Auto")},
       {0, NULL}}},
   { MNOTE_PENTAX2_TAG_AUTO_AFPOINT,
@@ -248,13 +248,13 @@ static const struct {
       {3, N_("Fluorescent")},
       {4, N_("Tungsten")},
       {5, N_("Manual")},
-      {6, N_("Daylight Fluorescent")},
-      {7, N_("Daywhite Fluorescent")},
-      {8, N_("White Fluorescent")},
+      {6, N_("Daylight fluorescent")},
+      {7, N_("Day white fluorescent")},
+      {8, N_("White fluorescent")},
       {9, N_("Flash")},
       {10, N_("Cloudy")},
       {0xfffe, N_("Unknown")},
-      {0xffff, N_("User Selected")},
+      {0xffff, N_("User selected")},
       {0, NULL}}},
   {MNOTE_CASIO2_TAG_BESTSHOT_MODE, 
     { {0, N_("Off")},
@@ -290,9 +290,9 @@ static const struct {
     { {0,   0, N_("Auto")},
       {5,   0, N_("Portrait")},
       {53,  0, N_("Underwater")},
-      {255, 0, N_("Digital Filter?")},
+      {255, 0, N_("Digital filter?")},
       {5,   1, N_("Portrait")},
-      {9,   1, N_("Night Scene")},
+      {9,   1, N_("Night scene")},
       {13,  1, N_("Candlelight")},
       {15,  1, N_("Macro")},
       {53,  1, N_("Underwater")},
@@ -400,27 +400,51 @@ mnote_pentax_entry_get_value (MnotePentaxEntry *entry,
 			entry->size);
 		break;
 	case MNOTE_PENTAX_TAG_TZ_CITY:
-		CF (entry->format, EXIF_FORMAT_UNDEFINED, val, maxlen);
-		CC (entry->components, 4, val, maxlen);
-		strncpy (val, (char*)entry->data, MIN(maxlen, entry->size));
-		break;
 	case MNOTE_PENTAX_TAG_TZ_DST:
 		CF (entry->format, EXIF_FORMAT_UNDEFINED, val, maxlen);
 		CC (entry->components, 4, val, maxlen);
 		strncpy (val, (char*)entry->data, MIN(maxlen, entry->size));
 		break;
+	case MNOTE_PENTAX2_TAG_DATE:
+		CF (entry->format, EXIF_FORMAT_UNDEFINED, val, maxlen);
+		CC (entry->components, 4, val, maxlen);
+		/* Note: format is UNDEFINED, not SHORT -> order is fixed: MOTOROLA */
+		vs = exif_get_short (entry->data, EXIF_BYTE_ORDER_MOTOROLA);
+		snprintf (val, maxlen, "%i:%02i:%02i", vs, entry->data[2], entry->data[3]);
+		break;
+	case MNOTE_PENTAX2_TAG_TIME:
+		CF (entry->format, EXIF_FORMAT_UNDEFINED, val, maxlen);
+		CC2 (entry->components, 3, 4, val, maxlen);
+		snprintf (val, maxlen, "%02i:%02i:%02i", entry->data[0], entry->data[1], entry->data[2]);
+		break;
 	default:
 		switch (entry->format) {
 		case EXIF_FORMAT_ASCII:
 		  strncpy (val, (char *)entry->data, MIN(maxlen, entry->size));
 		  break;
 		case EXIF_FORMAT_SHORT:
-		  vs = exif_get_short (entry->data, entry->order);
-		  snprintf (val, maxlen, "%i", vs);
+		  {
+			const unsigned char *data = entry->data;
+		  	size_t k, len = strlen(val);
+		  	for(k=0; k<entry->components; k++) {
+				vs = exif_get_short (data, entry->order);
+				snprintf (val+len, maxlen-len, "%i ", vs);
+				len = strlen(val);
+				data += 2;
+			}
+		  }
 		  break;
 		case EXIF_FORMAT_LONG:
-		  vl = exif_get_long (entry->data, entry->order);
-		  snprintf (val, maxlen, "%li", (long int) vl);
+		  {
+			const unsigned char *data = entry->data;
+		  	size_t k, len = strlen(val);
+		  	for(k=0; k<entry->components; k++) {
+				vl = exif_get_long (data, entry->order);
+				snprintf (val+len, maxlen-len, "%li", (long int) vl);
+				len = strlen(val);
+				data += 4;
+			}
+		  }
 		  break;
 		case EXIF_FORMAT_UNDEFINED:
 		default:
